@@ -7,6 +7,8 @@ minet <- function(dataset, method="mrnet", estimator="spearman", disc="none", nb
             net <- clr(mim)
       else if( method=="mrnet")
             net <- mrnet(mim)
+	  else if( method=="mrnetb")
+            net <- mrnetb(mim)
       else if( method=="aracne")
             net <- aracne(mim)
       else stop( "uknown method" )
