@@ -1,6 +1,11 @@
 #include "minet.h"
 
-SEXP mrnetold( SEXP Rmim, SEXP Rsize )
+SEXP mrnetb( SEXP Rmim, SEXP Rsize )
+{     
+      
+}
+
+SEXP mrnet( SEXP Rmim, SEXP Rsize )
 {     
       const double *mim;
       const int* size;
@@ -67,4 +72,5 @@ SEXP mrnetold( SEXP Rmim, SEXP Rsize )
       }
       UNPROTECT(5);
       return Rres;
-}
\ No newline at end of file
+}
+
